@@ -11,11 +11,11 @@ WG::API::WoWp - Modules to work with Wargaming.net Public API for World of Warpl
 
 =head1 VERSION
 
-Version v0.03
+Version v0.04
 
 =cut
 
-our $VERSION = 'v0.03';
+our $VERSION = 'v0.04';
 
 
 =head1 SYNOPSIS
@@ -24,7 +24,7 @@ Wargaming.net Public API is a set of API methods that provide access to Wargamin
 
 This module provide access to WG Public API
 
-    use WG::API::WoT::Account;
+    use WG::API::WoWp::Account;
 
     my $wowp = WG::API::WoWp::Account->new( { application_id => 'demo' } );
     ...
