@@ -11,11 +11,11 @@ WG::API::WoWp::Accounts - provide access to accounts info
 
 =head1 VERSION
 
-Version v0.03
+Version v0.04
 
 =cut
 
-our $VERSION = 'v0.03';
+our $VERSION = 'v0.04';
 
 =head1 METHODS
 
@@ -149,4 +149,4 @@ EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-1; # End of WG::API::Clans
+1; # End of WG::API::WoWp::Accounts
